@@ -106,19 +106,18 @@ class DefaultCallback(Callback):
             # everything is alright
             self.teardown_ok(param, engine)
             # we ack when ok hook has been successfully ran
-            engine.ack(param)
-            return
-        try:
-            raise exception
-        except KeyboardInterrupt:
-            engine.nack(param)
-            raise exception
-        except Exception:
-            pass
-        finally:
-            engine.nack(param)
+        else:
+            # NOTE(msimonin): we'd want to filter somehow the exception here: some
+            # exception might be expected from the user point of view (because he
+            # knows its application) so we could nack them to trigger a retry. In
+            # all other cases we mark the parameter as done but report the
+            # exception. Beware than nacking here everytime might lead to retry the
+            # same parameter using another process. So, for now we choose to mark
+            # the parameter as done regardless the exception.
             self.teardown_ko(param, engine, exception)
 
+        engine.ack(param)
+
     def teardown_ok(self, param, engine):
         pass
 
